=== added directory 'docs'
=== added file 'docs/Makefile.am'
--- docs/Makefile.am	1970-01-01 00:00:00 +0000
+++ docs/Makefile.am	2007-12-11 15:52:04 +0000
@@ -0,0 +1,15 @@
+INCLUDES = include
+
+EXTRA_DIST = memc_get.pod\
+	memc_set.pod
+
+man_MANS = memc_get.3\
+	memc_set.3
+
+memc_get.3: memc_get.pod 
+	pod2man  -r "" -s 3 memc_get.pod > memc_get.3
+	pod2man  -r "" -s 3 memc_set.pod > memc_set.3
+
+
+clean:
+	rm *.3

=== added file 'docs/memc_get.pod'
--- docs/memc_get.pod	1970-01-01 00:00:00 +0000
+++ docs/memc_get.pod	2007-12-11 15:52:04 +0000
@@ -0,0 +1,45 @@
+=head1 NAME
+
+memc_get, memc_mget
+
+=head1 UDF 
+
+Libmemcached User Defined Function for MySQL 
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+memc_get() is a UDF used to fetch an individual value from the memcached
+server from within MySQL. You must pass in a key to fetch the object.
+
+memcached_mget() is used to select multiple keys at once. For multiple key
+operations it is always faster to use this function. This function always
+works asynchronously. memcached_fetch() is then used to retrieve any keys
+found. No error is given on keys that are not found.
+
+=head1 RETURN
+
+Data stored in Memcached keyed by supplied hash value
+
+=head1 HOME
+
+To find out more information please check:
+L<http://hg.tangent.org/memcached_functions_mysql>
+L<http://tangent.org/552/libmemcached.html>
+
+=head1 INSTALL
+
+CREATE FUNCTION memc_get RETURNS STRING SONAME "libmemcached_functions_mysql.so";
+
+=head1 AUTHOR
+
+Patrick Galbraith, E<lt>patg@patg.netE<gt>
+Brian Aker, E<lt>brian@tangent.orgE<gt>
+
+=head1 SEE ALSO
+
+memc_set(), memc_delete()...
+
+=cut
+

=== added file 'docs/memc_set.pod'
--- docs/memc_set.pod	1970-01-01 00:00:00 +0000
+++ docs/memc_set.pod	2007-12-11 15:52:04 +0000
@@ -0,0 +1,42 @@
+=head1 NAME
+
+memc_set
+
+=head1 UDF 
+
+Libmemcached User Defined Function for MySQL 
+
+=head1 SYNOPSIS
+
+=head1 DESCRIPTION
+
+memc_set() is a UDF used to set an individual value from the memcached
+server from within MySQL. You must pass in a key and data value. The key
+you use to set the value with will be the key you use to subsequently 
+retrieve that data with (memc_get())
+
+=head1 RETURN
+
+NULL
+
+=head1 HOME
+
+To find out more information please check:
+L<http://hg.tangent.org/memcached_functions_mysql>
+L<http://tangent.org/552/libmemcached.html>
+
+=head1 INSTALL
+
+CREATE FUNCTION memc_set RETURNS INT SONAME "libmemcached_functions_mysql.so";
+
+=head1 AUTHOR
+
+Patrick Galbraith, E<lt>patg@patg.netE<gt>
+Brian Aker, E<lt>brian@tangent.orgE<gt>
+
+=head1 SEE ALSO
+
+memc_set(), memc_delete()...
+
+=cut
+

=== modified file 'src/servers.c'
--- src/servers.c	2007-12-07 16:37:04 +0000
+++ src/servers.c	2007-12-11 15:52:04 +0000
@@ -25,6 +25,10 @@
 char *memc_servers_set(UDF_INIT *initid, UDF_ARGS *args, char *result, unsigned long *length, char *is_null, char *error);
 /*void memc_servers_set_deinit(UDF_INIT *initid);*/
 
+my_bool memc_servers_behavior_set_init(UDF_INIT *initid, UDF_ARGS *args, char *message);
+char *memc_servers_behavior_set(UDF_INIT *initid, UDF_ARGS *args, char *result,
+                                unsigned long *length, char *is_null, char *error);
+/*void memc_servers_behavior_set_deinit(UDF_INIT *initid);*/
 
 my_bool memc_servers_set_init(UDF_INIT *initid, UDF_ARGS *args, char *message)
 {
@@ -64,22 +68,44 @@
   return (0);
 }
 
-memcached_return memc_get_servers(memcached_st *memc)
+
+
+/* memc_servers_behavior_set_init */
+my_bool memc_servers_behavior_set_init(UDF_INIT *initid, UDF_ARGS *args, char *message)
 {
+  unsigned int x;
   memcached_return rc;
-
+  memc_function_st *container;
+
+  /* Fail if not two args */
+  if (args->arg_count != 2)
+  {
+    strncpy(message, "Two argument for memc_servers_behavior_set - behavior type, value.\n", MYSQL_ERRMSG_SIZE);
+    return 1;
+  }
+
+  for (x= 0; x < args->arg_count; x++)
+    args->arg_type[x]= STRING_RESULT;
+
+  /*
+    Brian: Ok, so I clone here, but do I also need to lock ?
+  */
   pthread_mutex_lock(&memc_servers_mutex);
   rc= memcached_clone(container->memc, master_memc);
   pthread_mutex_unlock(&memc_servers_mutex);
 
-  return (unsigned int)rc;
+  /* initid->ptr keeps state for between memc_get_init and memc_get_deinit */
+  initid->ptr= (char *)container;
+
+  return 0;
 }
 
+/* memc_servers_behavior_set */
 char *memc_servers_behavior_set(UDF_INIT *initid, UDF_ARGS *args, char *result,
                                 unsigned long *length, char *is_null, char *error)
 {
   /*
-    is this another UDF? The user will be required to know the behavior values.
+    Brian: The user will be required to know the behavior values, right?.
     Should we allow lower-case?
   */
   memcached_behavior behavior;
@@ -110,14 +136,36 @@
   else if (! strcmp(args->args[0], "MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE"))
     behavior= MEMCACHED_BEHAVIOR_SOCKET_RECV_SIZE;
 
+
+  memc_function_st *container= (memc_function_st *)initid->ptr;
+
   pthread_mutex_lock(&memc_servers_mutex);
-  rc= memcached_behavior_set(container->memc, behavior, NULL );
+  /* Brian: can I just cast args->[1] as a void* ? */
+  rc= memcached_behavior_set(container->memc, (void *)args->[1], NULL );
   pthread_mutex_unlock(&memc_servers_mutex);
 }
 
+/*
+  Brian: what do you want to do with this? Is this another UDF?
+*/
 char *memc_servers_reset(UDF_INIT *initid, UDF_ARGS *args, char *result,
                                 unsigned long *length, char *is_null, char *error)
 {
   /* Dump all of host names - what/why is this? */
   /* host_reset(&new_host_list[count-1], NULL, 0, MEMCACHED_CONNECTION_UNKNOWN); */
 }
+
+
+/*
+   Brian: Is this a helper function for memc_servers_reset?
+*/
+memcached_return memc_get_servers(memcached_st *memc)
+{
+  memcached_return rc;
+
+  pthread_mutex_lock(&memc_servers_mutex);
+  rc= memcached_clone(container->memc, master_memc);
+  pthread_mutex_unlock(&memc_servers_mutex);
+
+  return (unsigned int)rc;
+}

